Learn R Programming

MCMChybridGP (version 5.4)

generateX0: Generate some initial points for the hybrid explore phase

Description

A function to randomly generate n0-many points within requested bounds, lb, ub. The points selected are to have the largest, minimum distance between any two points.

Usage

generateX0 (lb, ub, n0 = 10, npool = 100)

Arguments

lb

Lower (finite) bounds for points generated.

ub

Upper (finite) bounds for points generated.

n0

The number of points to be generated.

npool

The size of the pool of sets of randomly generated points in determining the best set of points.

Value

A matrix is returned which can then be supplied to hybrid.explore.

References

"Efficient MCMC Schemes for Computationally Expensive Posterior Distributions", Fielding, Nott and Liong (2011).

See Also

hybrid.explore,

Examples

Run this code
# NOT RUN {
lb <- c(-3,-3)
ub <- c(3,3)
X0 <- generateX0(lb, ub)
# }

Run the code above in your browser using DataLab